@@ -11,15 +11,23 @@ using TreeTools::count_bits;
 
 TREETOOLS_SPLITLIST_INIT
 
+void check_ntip(const double n) {
+  if (n > double(std::numeric_limits<int16>::max())) {
+    Rcpp::stop("This many tips are not (yet) supported.");
+  }
+}
+
 // [[Rcpp::export]]
 List cpp_robinson_foulds_distance (const RawMatrix x, const RawMatrix y, 
                                    const IntegerVector nTip) {
   if (x.cols() != y.cols()) {
     Rcpp::stop("Input splits must address same number of tips.");
   }
+  check_ntip(nTip[0]);
+  
   const SplitList a(x), b(y);
   const int16 last_bin = a.n_bins - 1,
-              n_tips = nTip[0],
+              n_tips = int16(nTip[0]),
               unset_tips = (n_tips % SL_BIN_SIZE) ? SL_BIN_SIZE - n_tips % SL_BIN_SIZE : 0;
   const splitbit unset_mask = ALL_ONES >> unset_tips;
   cost score = 0;
@@ -74,9 +82,11 @@ List cpp_robinson_foulds_info (const RawMatrix x, const RawMatrix y,
   if (x.cols() != y.cols()) {
     Rcpp::stop("Input splits must address same number of tips.");
   }
+  check_ntip(nTip[0]);
+  
   const SplitList a(x), b(y);
   const int16 last_bin = a.n_bins - 1,
-              n_tips = nTip[0],
+              n_tips = int16(nTip[0]),
               unset_tips = (n_tips % SL_BIN_SIZE) ? SL_BIN_SIZE - n_tips % SL_BIN_SIZE : 0;
   const splitbit unset_mask = ALL_ONES >> unset_tips;
   const double lg2_unrooted_n = lg2_unrooted[n_tips];
@@ -140,11 +150,13 @@ List cpp_matching_split_distance (const RawMatrix x, const RawMatrix y,
   if (x.cols() != y.cols()) {
     Rcpp::stop("Input splits must address same number of tips.");
   }
+  check_ntip(nTip[0]);
+  
   const SplitList a(x), b(y);
   const int16 most_splits = (a.n_splits > b.n_splits) ? a.n_splits : b.n_splits,
     split_diff = most_splits - 
       ((a.n_splits > b.n_splits) ? b.n_splits : a.n_splits),
-    n_tips = nTip[0],
+    n_tips = int16(nTip[0]),
     half_tips = n_tips / 2;
   if (most_splits == 0) {
     return List::create(Named("score") = 0);
@@ -204,10 +216,12 @@ List cpp_jaccard_similarity (const RawMatrix x, const RawMatrix y,
   if (x.cols() != y.cols()) {
     Rcpp::stop("Input splits must address same number of tips.");
   }
+  check_ntip(nTip[0]);
+  
   const SplitList a(x), b(y);
   const int16
     most_splits = (a.n_splits > b.n_splits) ? a.n_splits : b.n_splits,
-    n_tips = nTip[0]
+    n_tips = int16(nTip[0])
   ;
   const cost max_score = BIG;
   const double exponent = k[0], max_scoreL = max_score;
@@ -320,9 +334,11 @@ List cpp_msi_distance (const RawMatrix x, const RawMatrix y,
   if (x.cols() != y.cols()) {
     Rcpp::stop("Input splits must address same number of tips.");
   }
+  check_ntip(nTip[0]);
+  
   const SplitList a(x), b(y);
   const int16 most_splits = (a.n_splits > b.n_splits) ? a.n_splits : b.n_splits,
-              n_tips = nTip[0];
+              n_tips = int16(nTip[0]);
   const cost max_score = BIG;
   const double max_possible = lg2_unrooted[n_tips] - 
     lg2_rooted[int16((n_tips + 1) / 2)] - lg2_rooted[int16(n_tips / 2)];
@@ -347,9 +363,9 @@ List cpp_msi_distance (const RawMatrix x, const RawMatrix y,
       }
       const int16 n_same = n_tips - n_different;
       
-      score[ai][bi] = max_score - 
+      score[ai][bi] = cost(max_score - 
         ((max_score / max_possible) *
-          mmsi_score(n_same, n_a_and_b, n_different, n_a_only));
+          mmsi_score(n_same, n_a_and_b, n_different, n_a_only)));
     }
     for (int16 bi = b.n_splits; bi < most_splits; ++bi) {
       score[ai][bi] = max_score;
@@ -391,13 +407,15 @@ List cpp_mutual_clustering (const RawMatrix x, const RawMatrix y,
   if (x.cols() != y.cols()) {
     Rcpp::stop("Input splits must address same number of tips.");
   }
+  check_ntip(nTip[0]);
+  
   const SplitList a(x), b(y);
   const bool a_has_more_splits = (a.n_splits > b.n_splits);
   const int16
     most_splits = a_has_more_splits ? a.n_splits : b.n_splits,
     a_extra_splits = a_has_more_splits ? most_splits - b.n_splits : 0,
     b_extra_splits = a_has_more_splits ? 0 : most_splits - a.n_splits,
-    n_tips = nTip[0]
+    n_tips = int16(nTip[0])
   ;
   if (most_splits == 0 || n_tips == 0) {
     return List::create(Named("score") = 0,
@@ -411,7 +429,7 @@ List cpp_mutual_clustering (const RawMatrix x, const RawMatrix y,
   int16 exact_matches = 0;
   // NumericVector zero-initializes [so does make_unique]
   // match will have one added to it so numbering follows R; hence 0 = UNMATCHED
-  NumericVector a_match(a.n_splits);
+  IntegerVector a_match(a.n_splits);
   std::unique_ptr<int16[]> b_match = std::make_unique<int16[]>(b.n_splits);
   
   for (int16 ai = 0; ai != a.n_splits; ++ai) {
@@ -580,15 +598,18 @@ List cpp_shared_phylo (const RawMatrix x, const RawMatrix y,
   if (x.cols() != y.cols()) {
     Rcpp::stop("Input splits must address same number of tips.");
   }
+  check_ntip(nTip[0]);
+  
   const SplitList a(x), b(y);
   const int16
     most_splits = (a.n_splits > b.n_splits) ? a.n_splits : b.n_splits,
-    n_tips = nTip[0]
+    n_tips = int16(nTip[0]),
+    overlap_a = int16(n_tips + 1) / 2 // avoids promotion to int
   ;
   const cost max_score = BIG;
   const double
     lg2_unrooted_n = lg2_unrooted[n_tips],
-    best_overlap = one_overlap((n_tips + 1) / 2, n_tips / 2, n_tips),
+    best_overlap = one_overlap(overlap_a, n_tips / 2, n_tips),
     max_possible = lg2_unrooted_n - best_overlap
   ;
   
@@ -603,9 +624,8 @@ List cpp_shared_phylo (const RawMatrix x, const RawMatrix y,
                                           a.in_split[ai], b.in_split[bi],
                                           a.n_bins);
       
-      score[ai][bi] = spi_over ?
-        (spi_over - best_overlap) * (max_score / max_possible) :
-        max_score;
+      score[ai][bi] = spi_over == 0 ? max_score :
+        cost((spi_over - best_overlap) * (max_score / max_possible));
         
     }
     for (int16 bi = b.n_splits; bi < most_splits; ++bi) {
